==> nextcloud-32.0.2-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/firstrunwizard/l10n/is.js <==
OC.L10N.register(
    "firstrunwizard",
    {
    "First run wizard" : "Fyrsta-skiptis-leiðarvísir",
    "Add your profile information! For example your email is needed to receive notifications." : "Bættu við notandaupplýsingarnar þínar! Til dæmis þarftu að setja inn tölvupóstfangið þitt til að geta tekið við tilkynningum.",
    "Add your profile information! For example your email is needed to receive notifications and reset your password." : "Bættu við notandaupplýsingarnar þínar! Til dæmis þarftu að setja inn tölvupóstfangið þitt til að geta tekið við tilkynningum og endurstillt lykilorðið þitt.",
    "Add your profile information! Set a profile picture and full name for easier recognition across all features." : "Bættu við notandaupplýsingarnar þínar! Settu auðkennismynd og fullt nafn svo auðveldara verði að nota marga eiginleika.",
    "Add your profile information! Set a full name for easier recognition across all features." : "Bættu við notandaupplýsingarnar þínar! Settu inn fullt nafn svo auðveldara verði að nota marga eiginleika.",
    "Add your profile information! Set a profile picture for easier recognition across all features." : "Bættu við notandaupplýsingarnar þínar! Settu inn auðkennismynd svo auðveldara verði að nota marga eiginleika.",
    "App recommendation: Calendar" : "Forrit sem mælt er með: Calendar dagatalsforrit",
    "Schedule work & meetings, synced with all your devices." : "Áætlun vinnu og stefnumóta, samstillt við öll tækin þín.",
    "App recommendation: Contacts" : "Forrit sem mælt er með: Contacts tengiliðaforrit",
    "Keep your colleagues and friends in one place without leaking their private info." : "Hafðu samstarfsfólk og vini á einum stað án þess að leka einkaupplýsingum þeirra.",
    "App recommendation: Mail" : "Forrit sem mælt er með: Mail póstforrit",
    "Simple email app nicely integrated with Files, Contacts and Calendar." : "Einfalt og stílhreint tölvupóstforrit sem virkar með skráaforritinu, tengiliðum og dagatalinu.",
    "App recommendation: Tasks" : "Forrit sem mælt er með: Tasks verkefnaforrit",
    "Sync tasks from various devices with your Nextcloud and edit them online." : "Samstilltu verkefni af ýmsum tækjum við Nextcloud-svæðið þitt og breyttu verkum á netinu.",
    "App recommendation: Deck" : "Forrit sem mælt er með: Deck spjaldaforrit",
    "Kanban style organization for personal planning and team projects." : "Persónuleg áætlanagerð og skipulag verkefnisvinnu í Kanban-stíl.",
    "App recommendation: Forms" : "Forrit sem mælt er með: Forms-kannanaforrit",
    "Simple surveys and questionnaires, self-hosted" : "Einfaldar kannanir og spurningalistar, sjálfhýst",
    "App recommendation: Recognize" : "Forrit sem mælt er með: Recognize-merkingaforrit",
    "Smart media tagging for Nextcloud" : "Snjallmerkingar á margmiðlunarefni fyrir Nextcloud",
    "App recommendation: Group folders" : "Forrit sem mælt er með: Möppur hóps",
    "Admin-configured folders shared by everyone in a group." : "Möppur settar upp af kerfisstjóra sem deilt með öllum í hópi.",
    "App recommendation: Whiteboard" : "Forrit sem mælt er með: Whiteboard samvinnuforrit",
    "Create and share whiteboards with others and collaborate in real-time." : "Útbúðu og deildu vinnuborðum (whiteboard) með öðrum og stundaðu samstarf í rauntíma.",
    "Connect your calendar" : "Tengdu dagatalið þitt",
    "Connect your contacts" : "Tengdu tengiliðalistana þína",
    "Access files via WebDAV" : "Nálgastu skrár í gegnum WebDAV",
    "Download macOS/iOS configuration profile" : "Sækja macOS/iOS uppsetningasnið",
    "Desktop client" : "Skjáborðsforrit",
    "Android app on Google Play Store" : "Android-forrit úr Google Play forritasafni",
    "Android app on F-Droid" : "Android-forrit úr F-Droid",
    "iOS app" : "iOS-forrit",
    "About & What's new" : "Um forritið og hvað sé nýtt á döfinni",
    "A welcome and introduction wizard for Nextcloud" : "Kynning og leiðarvísir fyrir Nextcloud",
    "Download on Apple app store" : "Sækja úr App Store forritasafni",
    "Download on Google play store" : "Sækja úr Google Play forritasafni",
    "Go to previous page" : "Fara á fyrri síðu",
    "Close" : "Loka",
    "More about Nextcloud" : "Meira um Nextcloud",
    "Explore more apps ↗" : "Skoðaðu fleiri forrit ↗",
    "Extend the functionality of Nextcloud with hundreds of community-developed apps." : "Útvíkkaðu virkni Nextcloud með hundruðum viðbótarforrita hönnuðum í samfélagi notendanna.",
    "Get involved! ↗" : "Taktu þátt! ↗",
    "Be a part of the community that helps build, design, translate and promote Nextcloud!" : "Vertu hluti af samfélaginu sem byggir, hannar, þýðir og kynnir Nextcloud!",
    "Need help? ↗" : "Þarftu aðstoð? ↗",
    "Find out more about your Nextcloud setup with the admin, user or developer documentation." : "Skoðaðu ítarlegar upplýsingar um Nextcloud-uppsetninguna þína í hjálparskjölum fyrir stjórnendur, notendur og þróunaraðila.",
    "For large organisations ↗" : "Fyrir stór samtök eða fyrirtæki ↗",
    "Get Nextcloud Enterprise for mission critical environments where advanced security and compliance are important." : "Fáðu þér fyrirtækjaútgáfu Nextcloud fyrir mikilvæga vinnu þar sem þróað öryggi og samhæfni skipta mestu máli.",
    "Seamless integration with your devices." : "Hnökralaus samþætting milli tækjanna þinna.",
    "Sync your files across your devices with the desktop and mobile apps, and connect your calendar and contacts." : "Samstilltu skrárnar þínar á milli tækjanna þinna með forritum fyrir borðtölvur og snjalltæki og tengdu dagatalið og tengiliðina þína.",
    "Desktop app ↗" : "Borðtölvuforrit ↗",
    "Download For Windows, Mac OS and Linux." : "Sækja fyrir Windows, MacOS og Linux.",
    "Calendar and contacts ↗" : "Dagatal og tengiliðir ↗",
    "Connect your calendar and contacts with your devices." : "Tengdu dagatalið þitt og tengiliðina við öll tækin þín.",
    "Introducing Nextcloud Hub {version}" : "Við kynnum Nextcloud Hub {version}",
    "Welcome to {cloudName}!" : "Velkomin í {cloudName}!",
    "This Nextcloud is on version {version}" : "Þetta Nextcloud er í útgáfu {version}",
    "A collaboration platform that puts you in control" : "Samstarfskerfi sem gefur þér stjórnina",
    "Privacy" : "Meðferð persónuupplýsinga",
    "Host your data and files where you decide." : "Hýstu gögn þín og skrár þar sem þú ákveður.",
    "Productivity" : "Afkastahvetjandi",
    "Collaborate and communicate across any platform." : "Eigðu í samstarfi og samskiptum á milli allra hinna mismunandi stýrikerfa.",
    "Interoperability" : "Samverkandi",
    "Import and export anything you want with open standards." : "Inn- og útflutningur á eiginlega hverju sem er með opnum stöðlum.",
    "Community" : "Samfélag",
    "Enjoy constant improvements from a thriving open-source community." : "Njóttu stöðugrar framþróunar frá samfélaginu í kringum þennan opna hugbúnað.",
    "Nextcloud Hub {version} release" : "Nextcloud Hub {version} útgáfan",
    "Read more about it on the Nextcloud Hub {version} blog" : "Lestu meira um það á Nextcloud Hub {version} blogginu",
    "Find out more on the blog" : "Lestu meira um þetta á blogginu",
    "Read the Nextcloud Hub {version} blog" : "Lestu meira á Nextcloud Hub {version} blogginu",
    "Share your opinion about Nextcloud Hub {version}" : "Deildu skoðunum þínum um Nextcloud Hub {version}",
    "Share via email" : "Deila með tölvupósti",
    "Share on {socialMedia}" : "Deila á {socialMedia}",
    "New in Nextcloud Hub {version}" : "Nýtt í Nextcloud Hub {version}",
    "Connect other apps to {productName}" : "Tengdu önnur forrit við {productName}",
    "Besides the mobile apps and desktop client you can connect any other software that supports the WebDAV/CalDAV/CardDAV protocols to {productName}." : "Fyrir utan samstillingaforritin fyrir snjalltæki og vinnutölvur geturðu tengt hvert það forrit sem styður WebDAV/CalDAV/CardDAV samskiptamátana við {productName}.",
    "Apps to connect to {productName}" : "Forrit til að tengja við {productName}",
    "Set up sync clients using an {linkStart}app password{linkEnd}. That way you can make sure you are able to revoke access in case you lose that device." : "Settu upp samstillingarbiðlara með {linkStart}lykilorði forrits{linkEnd}. Þannig geturðu verið viss um að geta afturkallað aðgangsheimildir fari svo að þú tapir því tæki.",
    "Get the apps to sync your files" : "Náðu í forrit til að samstilla skrárnar þínar",
    "{productName} gives you access to your files wherever you are. Our easy to use desktop and mobile clients are available for all major platforms at zero cost." : "{productName} veitir þér aðgang að skránum þínum hvar sem þú ert. Tengiforritin okkar fyrir tölvur og snjalltæki eru fáanleg fyrir flest algengustu stýrikerfi án nokkurs kostnaðar.",
    "App for syncing" : "Forrit til samstillinga",
    "URL copied" : "Slóð afrituð",
    "Could not copy the URL, please copy manually" : "Tókst ekki að afrita slóðina, afritaðu hana handvirkt",
    "Server address" : "Vistfang þjóns",
    "Use this link to connect your apps and desktop client to this server:" : "Notaðu þessa slóð fyrir forritin þín til að tengjast þessum þjóni:",
    "Global redesign and usability lift" : "Almenn endurhönnun og endurbætur á notagildi",
    "New Office UI: colors, tabs, bars" : "Nýtt viðmót skrifstofuforrita: litir, flipar, stikur",
    "Performance and stability boost" : "Bætt afköst og stöðugleiki",
    "New AI Agency tools unlocked" : "Nýjum AI Agency verkfærum gefinn laus taumurinn",
    "Talk threads & live transcription" : "Spjallþræðir og umritun í beinni",
    "Calendar: date poll for participants" : "Dagatal: kosning um dagsetningar hjá þátttakendum",
    "Intuitive file search" : "Aðgengileg leit að skrám",
    "Teams 2.0 & quick Guest accounts" : "Teams 2.0 og fljótlegir gestaaðgangar",
    "Quick presets & many other admin updates" : "Fljótlegar forstillingar og margar aðrar uppfærslur fyrir kerfisstjóra",
    "Vue3, WebSockets and more OpenAPI for devs" : "Vue3, WebSockets og meira OpenAPI fyrir forritara",
    "… and much more!" : "… og margt fleira!",
    "Get to know the new features of Hub {version}" : "Kynntu þér nýja eiginleika í Hub {version}",
    "Nextcloud Hub 25 Autumn – Your digital workspace, ready in no time ⚡" : "Nextcloud Hub 25 Autumn er komið – Stafrænta vinnusvæðið þitt, tilbúið í hvelli  ⚡",
    "What's new?" : "Hvað er nýtt á döfinni?",
    "Nextcloud on all your devices" : "Nextcloud á öllum tækjunum þínum",
    "Nextcloud Hub {version}" : "Nextcloud Hub {version}",
    "Read more" : "Lesa meira",
    "Share on social media" : "Deila á samfélagsmiðlum",
    "Get started!" : "Komast í gang!",
    "End-to-end encryption in calls and web" : "Enda-í-enda dulritun í símtölum og á vefnum",
    "Performance improvements across all our products" : "Afkastabæting í öllum hugbúnaðnum okkar",
    "Thousands of tweaks for improved UX and stability" : "Þúsundir lagfæringa á notendaviðmóti og stöðugleika",
    "Your own new personal assistant" : "Ný þín eigin gervigreindaraðstoð",
    "Seamless file conversions" : "Hnökralaus umbreyting skráa",
    "Smarter team sharing with Team folders" : "Snjallari deiling teyma með teymamöppum",
    "Schedule meetings directly in Talk" : "Hægt að setj fundi á dagskrá beint í Talk-sjallforritinu",
    "Mail you love again: translations, summaries, and mentions" : "Tölvupóstur sem hentar þér: þýðingar, samantektir og hægt að minnast á e-n",
    "Nextcloud Hub 10 is here – your modular & unified digital workspace! 💫" : "Nextcloud Hub 10 er komið – allsherjar stafrænt vinnusvæði byggt úr einingum! 💫"
},
"nplurals=2; plural=(n % 10 != 1 || n % 100 == 11);");

==> nextcloud-32.0.6-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/firstrunwizard/l10n/is.js <==
OC.L10N.register(
    "firstrunwizard",
    {
    "First run wizard" : "Fyrsta-skiptis-leiðarvísir",
    "Add your profile information! For example your email is needed to receive notifications." : "Bættu við notandaupplýsingarnar þínar! Til dæmis þarftu að setja inn tölvupóstfangið þitt til að geta tekið við tilkynningum.",
    "Add your profile information! For example your email is needed to receive notifications and reset your password." : "Bættu við notandaupplýsingarnar þínar! Til dæmis þarftu að setja inn tölvupóstfangið þitt til að geta tekið við tilkynningum og endurstillt lykilorðið þitt.",
    "Add your profile information! Set a profile picture and full name for easier recognition across all features." : "Bættu við notandaupplýsingarnar þínar! Settu auðkennismynd og fullt nafn svo auðveldara verði að nota marga eiginleika.",
    "Add your profile information! Set a full name for easier recognition across all features." : "Bættu við notandaupplýsingarnar þínar! Settu inn fullt nafn svo auðveldara verði að nota marga eiginleika.",
    "Add your profile information! Set a profile picture for easier recognition across all features." : "Bættu við notandaupplýsingarnar þínar! Settu inn auðkennismynd svo auðveldara verði að nota marga eiginleika.",
    "App recommendation: Calendar" : "Forrit sem mælt er með: Calendar dagatalsforrit",
    "Schedule work & meetings, synced with all your devices." : "Áætlun vinnu og stefnumóta, samstillt við öll tækin þín.",
    "App recommendation: Contacts" : "Forrit sem mælt er með: Contacts tengiliðaforrit",
    "Keep your colleagues and friends in one place without leaking their private info." : "Hafðu samstarfsfólk og vini á einum stað án þess að leka einkaupplýsingum þeirra.",
    "App recommendation: Mail" : "Forrit sem mælt er með: Mail póstforrit",
    "Simple email app nicely integrated with Files, Contacts and Calendar." : "Einfalt og stílhreint tölvupóstforrit sem virkar með skráaforritinu, tengiliðum og dagatalinu.",
    "App recommendation: Tasks" : "Forrit sem mælt er með: Tasks verkefnaforrit",
    "Sync tasks from various devices with your Nextcloud and edit them online." : "Samstilltu verkefni af ýmsum tækjum við Nextcloud-svæðið þitt og breyttu verkum á netinu.",
    "App recommendation: Deck" : "Forrit sem mælt er með: Deck spjaldaforrit",
    "Kanban style organization for personal planning and team projects." : "Persónuleg áætlanagerð og skipulag verkefnisvinnu í Kanban-stíl.",
    "App recommendation: Forms" : "Forrit sem mælt er með: Forms-kannanaforrit",
    "Simple surveys and questionnaires, self-hosted" : "Einfaldar kannanir og spurningalistar, sjálfhýst",
    "App recommendation: Recognize" : "Forrit sem mælt er með: Recognize-merkingaforrit",
    "Smart media tagging for Nextcloud" : "Snjallmerkingar á margmiðlunarefni fyrir Nextcloud",
    "App recommendation: Group folders" : "Forrit sem mælt er með: Möppur hóps",
    "Admin-configured folders shared by everyone in a group." : "Möppur settar upp af kerfisstjóra sem deilt með öllum í hópi.",
    "App recommendation: Whiteboard" : "Forrit sem mælt er með: Whiteboard samvinnuforrit",
    "Create and share whiteboards with others and collaborate in real-time." : "Útbúðu og deildu vinnuborðum (whiteboard) með öðrum og stundaðu samstarf í rauntíma.",
    "Connect your calendar" : "Tengdu dagatalið þitt",
    "Connect your contacts" : "Tengdu tengiliðalistana þína",
    "Access files via WebDAV" : "Nálgastu skrár í gegnum WebDAV",
    "Download macOS/iOS configuration profile" : "Sækja macOS/iOS uppsetningasnið",
    "Desktop client" : "Skjáborðsforrit",
    "Android app on Google Play Store" : "Android-forrit úr Google Play forritasafni",
    "Android app on F-Droid" : "Android-forrit úr F-Droid",
    "iOS app" : "iOS-forrit",
    "About & What's new" : "Um forritið og hvað sé nýtt á döfinni",
    "A welcome and introduction wizard for Nextcloud" : "Kynning og leiðarvísir fyrir Nextcloud",
    "Download on Apple app store" : "Sækja úr App Store forritasafni",
    "Download on Google play store" : "Sækja úr Google Play forritasafni",
    "Go to previous page" : "Fara á fyrri síðu",
    "Close" : "Loka",
    "More about Nextcloud" : "Meira um Nextcloud",
    "Explore more apps ↗" : "Skoðaðu fleiri forrit ↗",
    "Extend the functionality of Nextcloud with hundreds of community-developed apps." : "Útvíkkaðu virkni Nextcloud með hundruðum viðbótarforrita hönnuðum í samfélagi notendanna.",
    "Get involved! ↗" : "Taktu þátt! ↗",
    "Be a part of the community that helps build, design, translate and promote Nextcloud!" : "Vertu hluti af samfélaginu sem byggir, hannar, þýðir og kynnir Nextcloud!",
    "Need help? ↗" : "Þarftu aðstoð? ↗",
    "Find out more about your Nextcloud setup with the admin, user or developer documentation." : "Skoðaðu ítarlegar upplýsingar um Nextcloud-uppsetninguna þína í hjálparskjölum fyrir stjórnendur, notendur og þróunaraðila.",
    "For large organisations ↗" : "Fyrir stór samtök eða fyrirtæki ↗",
    "Get Nextcloud Enterprise for mission critical environments where advanced security and compliance are important." : "Fáðu þér fyrirtækjaútgáfu Nextcloud fyrir mikilvæga vinnu þar sem þróað öryggi og samhæfni skipta mestu máli.",
    "Seamless integration with your devices." : "Hnökralaus samþætting milli tækjanna þinna.",
    "Sync your files across your devices with the desktop and mobile apps, and connect your calendar and contacts." : "Samstilltu skrárnar þínar á milli tækjanna þinna með forritum fyrir borðtölvur og snjalltæki og tengdu dagatalið og tengiliðina þína.",
    "Desktop app ↗" : "Borðtölvuforrit ↗",
    "Download For Windows, Mac OS and Linux." : "Sækja fyrir Windows, MacOS og Linux.",
    "Calendar and contacts ↗" : "Dagatal og tengiliðir ↗",
    "Connect your calendar and contacts with your devices." : "Tengdu dagatalið þitt og tengiliðina við öll tækin þín.",
    "Welcome to {cloudName}!" : "Velkomin í {cloudName}!",
    "Skip" : "Sleppa",
    "This Nextcloud is on version {version}" : "Þetta Nextcloud er í útgáfu {version}",
    "A collaboration platform that puts you in control" : "Samstarfskerfi sem gefur þér stjórnina",
    "Privacy" : "Meðferð persónuupplýsinga",
    "Host your data and files where you decide." : "Hýstu gögn þín og skrár þar sem þú ákveður.",
    "Productivity" : "Afkastahvetjandi",
    "Collaborate and communicate across any platform." : "Eigðu í samstarfi og samskiptum á milli allra hinna mismunandi stýrikerfa.",
    "Interoperability" : "Samverkandi",
    "Import and export anything you want with open standards." : "Inn- og útflutningur á eiginlega hverju sem er með opnum stöðlum.",
    "Community" : "Samfélag",
    "Enjoy constant improvements from a thriving open-source community." : "Njóttu stöðugrar framþróunar frá samfélaginu í kringum þennan opna hugbúnað.",
    "Nextcloud Hub {version} release" : "Nextcloud Hub {version} útgáfan",
    "Read more about it on the Nextcloud Hub {version} blog" : "Lestu meira um það á Nextcloud Hub {version} blogginu",
    "Find out more on the blog" : "Lestu meira um þetta á blogginu",
    "Read the Nextcloud Hub {version} blog" : "Lestu meira á Nextcloud Hub {version} blogginu",
    "Share your opinion about Nextcloud Hub {version}" : "Deildu skoðunum þínum um Nextcloud Hub {version}",
    "Share via email" : "Deila með tölvupósti",
    "Share on {socialMedia}" : "Deila á {socialMedia}",
    "New in Nextcloud Hub {version}" : "Nýtt í Nextcloud Hub {version}",
    "Connect other apps to {productName}" : "Tengdu önnur forrit við {productName}",
    "Besides the mobile apps and desktop client you can connect any other software that supports the WebDAV/CalDAV/CardDAV protocols to {productName}." : "Fyrir utan samstillingaforritin fyrir snjalltæki og vinnutölvur geturðu tengt hvert það forrit sem styður WebDAV/CalDAV/CardDAV samskiptamátana við {productName}.",
    "Apps to connect to {productName}" : "Forrit til að tengja við {productName}",
    "Set up sync clients using an {linkStart}app password{linkEnd}. That way you can make sure you are able to revoke access in case you lose that device." : "Settu upp samstillingarbiðlara með {linkStart}lykilorði forrits{linkEnd}. Þannig geturðu verið viss um að geta afturkallað aðgangsheimildir fari svo að þú tapir því tæki.",
    "Get the apps to sync your files" : "Náðu í forrit til að samstilla skrárnar þínar",
    "{productName} gives you access to your files wherever you are. Our easy to use desktop and mobile clients are available for all major platforms at zero cost." : "{productName} veitir þér aðgang að skránum þínum hvar sem þú ert. Tengiforritin okkar fyrir tölvur og snjalltæki eru fáanleg fyrir flest algengustu stýrikerfi án nokkurs kostnaðar.",
    "App for syncing" : "Forrit til samstillinga",
    "URL copied" : "Slóð afrituð",
    "Could not copy the URL, please copy manually" : "Tókst ekki að afrita slóðina, afritaðu hana handvirkt",
    "Server address" : "Vistfang þjóns",
    "Use this link to connect your apps and desktop client to this server:" : "Notaðu þessa slóð fyrir forritin þín til að tengjast þessum þjóni:",
    "Get to know the new features of Hub {version}" : "Kynntu þér nýja eiginleika í Hub {version}",
    "What's new?" : "Hvað er nýtt á döfinni?",
    "Nextcloud on all your devices" : "Nextcloud á öllum tækjunum þínum",
    "Nextcloud Hub {version}" : "Nextcloud Hub {version}",
    "Share on social media" : "Deila á samfélagsmiðlum",
    "Get started!" : "Komast í gang!",
    "Introducing Nextcloud Hub {version}" : "Við kynnum Nextcloud Hub {version}",
    "End-to-end encryption in calls and web" : "Enda-í-enda dulritun í símtölum og á vefnum",
    "Performance improvements across all our products" : "Afkastabæting í öllum hugbúnaðnum okkar",
    "Thousands of tweaks for improved UX and stability" : "Þúsundir lagfæringa á notendaviðmóti og stöðugleika",
    "Your own new personal assistant" : "Ný þín eigin gervigreindaraðstoð",
    "Seamless file conversions" : "Hnökralaus umbreyting skráa",
    "Smarter team sharing with Team folders" : "Snjallari deiling teyma með teymamöppum",
    "Schedule meetings directly in Talk" : "Hægt að setj fundi á dagskrá beint í Talk-sjallforritinu",
    "Mail you love again: translations, summaries, and mentions" : "Tölvupóstur sem hentar þér: þýðingar, samantektir og hægt að minnast á e-n",
    "Nextcloud Hub 10 is here – your modular & unified digital workspace! 💫" : "Nextcloud Hub 10 er komið – allsherjar stafrænt vinnusvæði byggt úr einingum! 💫",
    "Read more" : "Lesa meira",
    "Global redesign and usability lift" : "Almenn endurhönnun og endurbætur á notagildi",
    "New Office UI: colors, tabs, bars" : "Nýtt viðmót skrifstofuforrita: litir, flipar, stikur",
    "Performance and stability boost" : "Bætt afköst og stöðugleiki",
    "New AI Agency tools unlocked" : "Nýjum AI Agency verkfærum gefinn laus taumurinn",
    "Talk threads & live transcription" : "Spjallþræðir og umritun í beinni",
    "Calendar: date poll for participants" : "Dagatal: kosning um dagsetningar hjá þátttakendum",
    "Intuitive file search" : "Aðgengileg leit að skrám",
    "Teams 2.0 & quick Guest accounts" : "Teams 2.0 og fljótlegir gestaaðgangar",
    "Quick presets & many other admin updates" : "Fljótlegar forstillingar og margar aðrar uppfærslur fyrir kerfisstjóra",
    "Vue3, WebSockets and more OpenAPI for devs" : "Vue3, WebSockets og meira OpenAPI fyrir forritara",
    "… and much more!" : "… og margt fleira!",
    "Nextcloud Hub 25 Autumn – Your digital workspace, ready in no time ⚡" : "Nextcloud Hub 25 Autumn er komið – Stafrænta vinnusvæðið þitt, tilbúið í hvelli  ⚡"
},
"nplurals=2; plural=(n % 10 != 1 || n % 100 == 11);");
